@@ -6,7 +6,7 @@
 #      *                                                                *
 #      ******************************************************************
 
-from dpeaDPi.DPiNetwork import DPiNetwork
+from DPiNetwork import DPiNetwork
 dpiNetwork = DPiNetwork()
 
 
@@ -89,6 +89,7 @@ class DPiRobot:
     STATE_STOPPED = 6                           # robot is stopped, waiting for waypoints from the host
     STATE_PREPARING_TO_MOVE = 7                 # robot has received 1 or more waypoints but hasn't started moving yet
     STATE_MOVING = 8                            # moving to next waypoint
+    STATE_E_STOPPED_PRESSED = 9                 # E-Stop button is pressed
     STATE_WAYPOINT_BUFFER_FULL_FLAG = 0x80      # this bit set in status byte if waypoint buffer is full
 
     #
